@@ -394,7 +394,7 @@ my $FUNCTIONS = {
 
 
 
-@EXPORT_OK = ( keys(%$FUNCTIONS), qw(get_entries));
+@EXPORT_OK = keys(%$FUNCTIONS);
 
 %EXPORT_TAGS = (
     'all' => \@EXPORT_OK
@@ -408,16 +408,16 @@ my $init = 0;
 sub udev_version {
     my $full_path = which('udevadm');
 
-    if(!defined $full_path) {
-        for(@{ +UDEVADM_LOCATIONS }) {
-            if(-f) {
+    unless (defined($full_path)) {
+        for (@{ +UDEVADM_LOCATIONS }) {
+            if (-f) {
                 $full_path = $_;
                 last;
             }
         }
     }
 
-    if(!defined $full_path) {
+    unless (defined($full_path)) {
         $@ = "Can't find `udevadm` utility";
         return undef;
     }
@@ -426,10 +426,10 @@ sub udev_version {
     {
         local $SIG{__WARN__} = sub {}; # silence shell output if error
 
-        if(open my $ph, '-|', $full_path, '--version') {
+        if (open(my $ph, '-|', $full_path, '--version')) {
             my $out = <$ph>;
 
-            if(defined($out) && $out =~ /^(\d+)\s*$/) {
+            if (defined($out) && $out =~ /^(\d+)\s*$/) {
                 return $1;
             }
 
@@ -447,69 +447,40 @@ sub udev_version {
 my $_function_not_attach = sub {
     my $udev_version = udev_version();
 
-    die "Function '".$_[0]."' not attached from udev library\n".
-        "`udevadm` version: ".(defined($udev_version) ?$udev_version :'unknown')."\n";
+    die("function '".$_[0]."' not attached from udev library\n`udevadm` ".
+        "version: ".(defined($udev_version) ?$udev_version :'unknown')."\n");
 };
 
 
 
-sub get_entries {
-    my $entry = shift;
-
-    if (wantarray) { # TODO deprecated
-        my @a = ();
-
-        while (defined($entry)) {
-            push @a, udev_list_entry_get_name($entry);
-            $entry = udev_list_entry_get_next($entry);
-        }
-
-        return @a;
-    }
-
-
-    my %h = ();
-
-    while (defined($entry)) {
-        $h{ udev_list_entry_get_name($entry) } = udev_list_entry_get_value($entry);
-        $entry = udev_list_entry_get_next($entry);
-    }
-
-    return \%h;
-}
-
-
-
 sub init {
     return 1 if $init;
 
 
-    my ($libudev) = find_lib(
-        lib => 'udev'
-    );
-    if(!$libudev) {
+    my ($libudev) = find_lib(lib => 'udev');
+    unless ($libudev) {
         $@ = "Can't find udev library";
         return 0;
     }
 
     my $udev_version = udev_version() || 0;
 
-    my $ffi = FFI::Platypus->new;
+    my $ffi = FFI::Platypus->new();
     $ffi->lib($libudev);
 
-    if(!$ffi->type('dev_t')) {
+    unless ($ffi->type('dev_t')) {
         $@ = "Can't find \"dev_t\" type";
         return 0;
     }
 
-    for my $funct (keys %$FUNCTIONS) {
+    for my $funct (keys(%$FUNCTIONS)) {
         eval {
             # attach locks the function and the FFI::Platypus instance into memory permanently,
             # since there is no way to deallocate an xsub
             $ffi->attach($funct => $FUNCTIONS->{$funct}{ffi_data}[0] => $FUNCTIONS->{$funct}{ffi_data}[1]);
         };
-        if($@) {
-            if(!exists($FUNCTIONS->{$funct}{since}) || $udev_version >= $FUNCTIONS->{$funct}{since}) {
+        if ($@) {
+            if (!exists($FUNCTIONS->{$funct}{since}) || $udev_version >= $FUNCTIONS->{$funct}{since}) {
                 $@ = $1
                     if $@ =~ m{^(.*)\s+at\s.*line\s\d+.}xms;
 
@@ -522,7 +493,7 @@ sub init {
         }
 
         # function attached
-        delete $FUNCTIONS->{$funct};
+        delete($FUNCTIONS->{$funct});
     }
 
     return ++$init;
